[wiaflos-devel] COMMIT - r243 - trunk/wiaflos/server

svn at linuxrulz.org svn at linuxrulz.org
Sun Aug 24 17:14:30 GMT 2008


Author: nkukard
Date: 2008-08-24 17:14:30 +0000 (Sun, 24 Aug 2008)
New Revision: 243

Modified:
   trunk/wiaflos/server/GL.pm
   trunk/wiaflos/server/Reporting.pm
Log:
* Fixed credit and debit balance being used in templates


Modified: trunk/wiaflos/server/GL.pm
===================================================================
--- trunk/wiaflos/server/GL.pm	2008-08-24 17:03:56 UTC (rev 242)
+++ trunk/wiaflos/server/GL.pm	2008-08-24 17:14:30 UTC (rev 243)
@@ -438,8 +438,6 @@
 # @li Level Depth level of this account
 sub getGLAccountTree
 {
-	use Data::Dumper;
-
 	# Grab account list
 	my $accounts = getGLAccounts();
 	if (ref $accounts ne "ARRAY") {

Modified: trunk/wiaflos/server/Reporting.pm
===================================================================
--- trunk/wiaflos/server/Reporting.pm	2008-08-24 17:03:56 UTC (rev 242)
+++ trunk/wiaflos/server/Reporting.pm	2008-08-24 17:14:30 UTC (rev 243)
@@ -247,6 +247,8 @@
 			$i->{'Number'} = $account->{'Number'};
 			$i->{'Name'} = $account->{'Name'};
 
+			$i->{'DebitBalance'} = $account->{'DebitBalance'};
+			$i->{'CreditBalance'} = $account->{'CreditBalance'};
 			$i->{'Balance'} = $account->{'Balance'};
 
 			# Check balance
@@ -274,7 +276,7 @@
 				}
 			}
 
 			# File under account number
 			$vars->{'AccountBalances'}{$i->{'Number'}} = $i;
 
 			return $i;
@@ -274,7 +276,7 @@
 			}
 
-			# File under account number
+			# File balance under account number
 			$vars->{'AccountBalances'}{$i->{'Number'}} = $i;
 



More information about the wiaflos-devel mailing list